LogicalFilter class abstract

Base class for logical filters.

Inheritance
Implementers
Available extensions

Constructors

LogicalFilter()

Properties

hashCode int
The hash code for this object.
no setterinherited
name String

Available on Filter, provided by the FilterExt extension

Returns the name of this filter type.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

and(Filter other) Filter
Returns a logical AND combination of this filter and other.
inherited
apply(Document doc) bool
Applies the filter to the document.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not() Filter
Returns a logical NOT negation of this filter.
inherited
or(Filter other) Filter
Returns a logical OR combination of this filter and other.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator &(Filter other) Filter
Operator overload for a logical AND combination of this filter and other.
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator |(Filter other) Filter
Operator overload for a logical OR combination of this filter and other.
inherited
operator ~() Filter
Operator overload for a logical NOT negation of this filter.
inherited