PullModifier class

A modifier that removes elements matching predicate from the array at selector.

Inheritance

Constructors

PullModifier(String selector, bool predicate(dynamic))
Creates a new PullModifier targeting selector with the matching predicate.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
predicate bool Function(dynamic)
The predicate callback filter.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selector String
The selector path to the target array field.
final

Methods

apply(Document doc) → void
Applies the modifier to the document.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited