ValueNotifierReactivityProvider<I> class

A reactivity provider that transforms cursor query results into a ValueNotifier.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
watch(FindCursor<I> cursor) ValueNotifier<List<Document<I>>>
Transforms the query results of cursor into a reactive ValueNotifier.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited