IncModifier class
A modifier that increments the field at selector by value.
Properties
-
defaultValue
→ num
-
The default value to fall back on if the field is null.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
selector
→ String
-
The selector path to the target field.
final
-
value
→ num
-
The value to increment by.
final
Methods
-
apply(Document doc)
→ void
-
Applies the modifier to the document.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
override